@@ -5,12 +5,12 @@ use warnings;
 
 package MongoDBI::Document::Config;
 {
-  $MongoDBI::Document::Config::VERSION = '0.0.4';
+  $MongoDBI::Document::Config::VERSION = '0.0.5';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.4'; # VERSION
+our $VERSION = '0.0.5'; # VERSION
 
 use Moose::Role; # is trait (++ :)
 
@@ -58,6 +58,14 @@ has indexes => (
 );
 
 
+has options => (
+    is      => 'rw',
+    isa     => 'HashRef',
+    lazy    => 1,
+    default => sub { { safe => 1 } }
+);
+
+
 has searches  => (
     is      => 'rw',
     isa     => 'HashRef',
@@ -65,21 +73,6 @@ has searches  => (
 );
 
 
-sub set_database {
-    my ($self, @args) = @_;
-    
-    my %args = @args == 1 ? (name => $args[0]) : @args;
-    
-    $args{name} ||= $self->database->{name};
-    
-    die "Please specify the name of the database" unless $args{name};
-    
-    $self->database->{$_} = $args{$_} for keys %args;
-    
-    return $self;
-}
-
-
 sub set_collection {
     my ($self, @args) = @_;
     
@@ -123,6 +116,21 @@ sub set_collection {
     return $self;
 }
 
+
+sub set_database {
+    my ($self, @args) = @_;
+    
+    my %args = @args == 1 ? (name => $args[0]) : @args;
+    
+    $args{name} ||= $self->database->{name};
+    
+    die "Please specify the name of the database" unless $args{name};
+    
+    $self->database->{$_} = $args{$_} for keys %args;
+    
+    return $self;
+}
+
 1;
 __END__
 =pod
@@ -133,7 +141,7 @@ MongoDBI::Document::Config - Configuration for a MongoDBI Document Class
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -144,6 +152,9 @@ version 0.0.4
     $cds->config->set_collection('some_classes');
     $cds->config->set_database('test');
     
+    # set raise and print errors like in DBI
+    $cds->config->set_options(safe => 1);
+    
     1;
 
 =head1 DESCRIPTION
@@ -241,6 +252,23 @@ L<MongoDBI::Document::Sugar>. Access the indexes attribute directly as follows:
     # print field names of the first registered index
     print $_ for keys $cds->config->indexes->[0]->[0]; 
 
+=head2 options
+
+The options attribute may contains the arguments that will be passed to the
+L<MongoDB::Collection> collection altering operations such as insert, update,
+remove and save.
+
+Note: Setting this attribute will affect those collection altering operations.
+Note: Safe Mode is enabled by default!
+
+Access it directly as follows:
+
+    package main;
+
+    my $cds = CDDB::Album;
+    
+    $cds->config->options->{safe} = 0;
+
 =head2 searches
 
 The searches attribute contains a hashref of filter specifications generated by
@@ -261,21 +289,6 @@ L<MongoDBI::Document::Sugar>. Access the searches attribute directly as follows:
 
 =head1 METHODS
 
-=head2 set_database
-
-The set_database method stashes the attributes that will used to create a
-L<MongoDB::Database> object when the database connection is made. Utilize this
-method as follows:
-
-    package main;
-
-    my $cds = CDDB::Album;
-    
-    $cds->config->set_database('test');
-    
-    # semantically correct
-    $cds->config->set_database(name => 'test');
-
 =head2 set_collection
 
 The set_collection method stashes the attributes that will used to create a
@@ -307,6 +320,21 @@ method as follows:
     * upper/uc - uppercase string
     * default - same as (decamel, undercolon, lower, plural)
 
+=head2 set_database
+
+The set_database method stashes the attributes that will used to create a
+L<MongoDB::Database> object when the database connection is made. Utilize this
+method as follows:
+
+    package main;
+
+    my $cds = CDDB::Album;
+    
+    $cds->config->set_database('test');
+    
+    # semantically correct
+    $cds->config->set_database(name => 'test');
+
 =head1 AUTHOR
 
 Al Newkirk <awncorp@cpan.org>
